@@ -31,13 +31,6 @@ REQUEST_HEADERS: list[RequestHeader] = [
         "experimental": False,
         "url": "/en-US/docs/Web/HTTP/Headers/Cache-Control",
     },
-    {
-        "section": "Caching",
-        "name": "Clear-Site-Data",
-        "description": "Clears browsing data (e.g. cookies, storage, cache) associated with the requesting website.",
-        "experimental": False,
-        "url": "/en-US/docs/Web/HTTP/Headers/Clear-Site-Data",
-    },
     {
         "section": "Conditionals",
         "name": "If-Match",
@@ -143,13 +136,6 @@ REQUEST_HEADERS: list[RequestHeader] = [
         "experimental": False,
         "url": "/en-US/docs/Web/HTTP/Headers/Origin",
     },
-    {
-        "section": "CORS",
-        "name": "Timing-Allow-Origin",
-        "description": "Specifies origins that are allowed to see values of attributes retrieved via features of the Resource Timing API, which would otherwise be reported as zero due to cross-origin restrictions.",
-        "experimental": False,
-        "url": "/en-US/docs/Web/HTTP/Headers/Timing-Allow-Origin",
-    },
     {
         "section": "Message body information",
         "name": "Content-Length",
@@ -220,13 +206,6 @@ REQUEST_HEADERS: list[RequestHeader] = [
         "experimental": False,
         "url": "/en-US/docs/Web/HTTP/Headers/Referer",
     },
-    {
-        "section": "Request context",
-        "name": "Referrer-Policy",
-        "description": "Governs which referrer information sent in the Referer header should be included with requests made.",
-        "experimental": False,
-        "url": "/en-US/docs/Web/HTTP/Headers/Referrer-Policy",
-    },
     {
         "section": "Request context",
         "name": "User-Agent",
@@ -318,13 +297,6 @@ REQUEST_HEADERS: list[RequestHeader] = [
         "experimental": False,
         "url": "/en-US/docs/Web/HTTP/Headers/X-Forwarded-Proto",
     },
-    {
-        "section": "Non-standard headers",
-        "name": "X-DNS-Prefetch-Control",
-        "description": "Controls DNS prefetching, a feature by which browsers proactively perform domain name resolution on both links that the user may choose to follow as well as URLs for items referenced by the document, including images, CSS, JavaScript, and so forth.",
-        "experimental": False,
-        "url": "/en-US/docs/Web/HTTP/Headers/X-DNS-Prefetch-Control",
-    },
     {
         "section": "Deprecated headers",
         "name": "Pragma",
@@ -332,13 +304,6 @@ REQUEST_HEADERS: list[RequestHeader] = [
         "experimental": False,
         "url": "/en-US/docs/Web/HTTP/Headers/Pragma",
     },
-    {
-        "section": "Deprecated headers",
-        "name": "Warning",
-        "description": "General warning information about possible problems.",
-        "experimental": False,
-        "url": "/en-US/docs/Web/HTTP/Headers/Warning",
-    },
     {
         "section": "Experimental headers",
         "name": "Origin-Isolation",
@@ -388,4 +353,60 @@ REQUEST_HEADERS: list[RequestHeader] = [
         "experimental": True,
         "url": "/en-US/docs/Web/HTTP/Headers/Sec-GPC",
     },
+    {
+        "section": "Content negotiation",
+        "name": "Accept-Charset",
+        "description": "Indicates which character encodings the client can understand.",
+        "experimental": False,
+        "url": "/en-US/docs/Web/HTTP/Headers/Accept-Charset",
+    },
+    {
+        "section": "Privacy",
+        "name": "DNT",
+        "description": "Expresses the user's tracking preference.",
+        "experimental": False,
+        "url": "/en-US/docs/Web/HTTP/Headers/DNT",
+    },
+    {
+        "section": "Controls",
+        "name": "Upgrade",
+        "description": "Requests an upgrade to a different protocol.",
+        "experimental": False,
+        "url": "/en-US/docs/Web/HTTP/Headers/Upgrade",
+    },
+    {
+        "section": "Security",
+        "name": "Sec-Fetch-Site",
+        "description": "Indicates the relationship between the request initiator's origin and the resource's origin.",
+        "experimental": False,
+        "url": "/en-US/docs/Web/HTTP/Headers/Sec-Fetch-Site",
+    },
+    {
+        "section": "Security",
+        "name": "Sec-Fetch-Mode",
+        "description": "Indicates the mode of the request.",
+        "experimental": False,
+        "url": "/en-US/docs/Web/HTTP/Headers/Sec-Fetch-Mode",
+    },
+    {
+        "section": "Security",
+        "name": "Sec-Fetch-User",
+        "description": "Indicates whether a navigation request was triggered by user activation.",
+        "experimental": False,
+        "url": "/en-US/docs/Web/HTTP/Headers/Sec-Fetch-User",
+    },
+    {
+        "section": "Security",
+        "name": "Sec-Fetch-Dest",
+        "description": "Indicates the destination of the request.",
+        "experimental": False,
+        "url": "/en-US/docs/Web/HTTP/Headers/Sec-Fetch-Dest",
+    },
+    {
+        "section": "Service Workers",
+        "name": "Service-Worker-Navigation-Preload",
+        "description": "Allows a service worker to request navigation preloads.",
+        "experimental": False,
+        "url": "/en-US/docs/Web/HTTP/Headers/Service-Worker-Navigation-Preload",
+    },
 ]
