@@ -1,3 +1,4 @@
+from rich.text import Text
 from textual.app import ComposeResult
 from textual.binding import Binding
 from textual.containers import Vertical
@@ -16,6 +17,7 @@ class ParamsTable(PostingDataTable):
 
     BINDINGS = [
         Binding("backspace", action="remove_row", description="Remove row"),
+        Binding("space", action="toggle_row", description="Toggle row"),
     ]
 
     def on_mount(self):
@@ -23,6 +25,7 @@ class ParamsTable(PostingDataTable):
         self.show_header = False
         self.cursor_type = "row"
         self.zebra_stripes = True
+        self.row_disable = True
         self.add_columns("Key", "Value")
 
     def watch_has_focus(self, value: bool) -> None:
@@ -31,10 +34,15 @@ class ParamsTable(PostingDataTable):
 
     def to_model(self) -> list[QueryParam]:
         params: list[QueryParam] = []
-        # TODO - handle enabled/disabled...
         for row_index in range(self.row_count):
             row = self.get_row_at(row_index)
-            params.append(QueryParam(name=row[0], value=row[1], enabled=True))
+            params.append(
+                QueryParam(
+                    name=row[0].plain if isinstance(row[0], Text) else row[0],
+                    value=row[1].plain if isinstance(row[1], Text) else row[1],
+                    enabled=self.is_row_enabled_at(row_index),
+                )
+            )
         return params
 
 
@@ -51,7 +59,7 @@ class QueryStringEditor(Vertical):
                 VariableInput(placeholder="Value"),
                 button_label="Add parameter",
             ),
-            empty_message="There are no parameters.",
+            empty_message="No query parameters",
         )
 
     @property
